==> transmission-1.05.tar.bz2: transmission-1.05/macosx/GroupsWindowController.h <==
/******************************************************************************
 * $Id: GroupsWindowController.h 4423 2008-01-02 16:55:05Z livings124 $
 *
 * Copyright (c) 2007-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>

@class CTGradient;

@interface GroupsWindowController : NSWindowController
{
    NSMutableArray * fGroups;
    
    IBOutlet NSTableView * fTableView;
    IBOutlet NSSegmentedControl * fAddRemoveControl;
    
    NSMutableDictionary * fCurrentColorDict;
}

+ (GroupsWindowController *) groups;

- (int) orderValueForIndex: (int) index;
- (CTGradient *) gradientForIndex: (int) index;
- (NSString *) nameForIndex: (int) index;
- (NSImage *) imageForIndex: (int) index isSmall: (BOOL) small;

- (void) addRemoveGroup: (id) sender;

- (NSMenu *) groupMenuWithTarget: (id) target action: (SEL) action isSmall: (BOOL) small;

@end

==> transmission-1.52.tar.bz2: transmission-1.52/macosx/GroupsWindowController.h <==
/******************************************************************************
 * $Id: GroupsWindowController.h 5339 2008-03-23 04:36:30Z livings124 $
 *
 * Copyright (c) 2007-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>

@class CTGradient;

@interface GroupsWindowController : NSWindowController
{
    IBOutlet NSTableView * fTableView;
    IBOutlet NSSegmentedControl * fAddRemoveControl;
    
    int fCurrentColorIndex;
}

+ (GroupsWindowController *) groupsWindow;

- (void) addRemoveGroup: (id) sender;

@end
